@@ -20,13 +20,9 @@ pub use object::Object;
 
 ///
 pub mod input;
-#[doc(inline)]
-pub use input::BytesToEntriesIter;
 
 /// Utilities to encode pack data entries and write them to a `Write` implementation to resemble a pack data file.
 pub mod output;
-#[doc(inline)]
-pub use output::{objects_to_entries_iter, EntriesToBytesIter};
 
 /// A slice into a pack file denoting a pack entry.
 ///
