@@ -29,9 +29,14 @@ pub trait Find {
     /// holding the object.
     ///
     /// _Note_ that the object database may have no notion of packs and thus always returns `None`.
-    fn location_by_id(&self, id: impl AsRef<git_hash::oid>, buf: &mut Vec<u8>) -> Option<crate::bundle::Location>;
+    fn location_by_oid(&self, id: impl AsRef<git_hash::oid>, buf: &mut Vec<u8>) -> Option<crate::bundle::Location>;
 
-    /// Return the [`PackEntry`] for `location` if it is backed by a pack.
+    /// Find the bundle matching `pack_id`, or `None` if there is no such pack.
+    ///
+    /// _Note_ that the object database may have no notion of packs and thus always returns `None`.
+    fn bundle_by_pack_id(&self, pack_id: u32) -> Option<&crate::Bundle>;
+
+    /// Return the [`Entry`] for `location` if it is backed by a pack.
     ///
     /// Note that this is only in the interest of avoiding duplicate work during pack generation.
     /// Pack locations can be obtained from a [`data::Object`].
@@ -40,7 +45,7 @@ pub trait Find {
     ///
     /// Custom implementations might be interested in providing their own meta-data with `object`,
     /// which currently isn't possible as the `Locate` trait requires GATs to work like that.
-    fn pack_entry_by_location(&self, location: &crate::bundle::Location) -> Option<PackEntry<'_>>;
+    fn entry_by_location(&self, location: &crate::bundle::Location) -> Option<Entry<'_>>;
 }
 
 mod ext {
@@ -206,10 +211,13 @@ pub mod existing_iter {
     }
 }
 
+/// An Entry in a pack providing access to its data.
+///
+/// Its commonly retrieved by reading from a pack index file followed by a read from a pack data file.
 #[derive(PartialEq, Eq, Debug, Hash, Ord, PartialOrd, Clone, Copy)]
 #[cfg_attr(feature = "serde1", derive(serde::Serialize, serde::Deserialize))]
-#[allow(missing_docs)] // TODO: docs
-pub struct PackEntry<'a> {
+#[allow(missing_docs)]
+pub struct Entry<'a> {
     /// The pack-data encoded bytes of the pack data entry as present in the pack file, including the header followed by compressed data.
     pub data: &'a [u8],
     /// The crc32 hash over the entirety of `data`, or None if the pack file format doesn't support it yet.
@@ -220,7 +228,7 @@ pub struct PackEntry<'a> {
 
 mod find_impls {
     use crate::bundle::Location;
-    use crate::{data::Object, find::PackEntry};
+    use crate::{data::Object, find::Entry, Bundle};
     use git_hash::oid;
     use std::ops::Deref;
 
@@ -239,12 +247,16 @@ mod find_impls {
             self.deref().find(id, buffer, pack_cache)
         }
 
-        fn location_by_id(&self, id: impl AsRef<oid>, buf: &mut Vec<u8>) -> Option<Location> {
-            self.deref().location_by_id(id, buf)
+        fn location_by_oid(&self, id: impl AsRef<oid>, buf: &mut Vec<u8>) -> Option<Location> {
+            self.deref().location_by_oid(id, buf)
         }
 
-        fn pack_entry_by_location(&self, object: &crate::bundle::Location) -> Option<PackEntry<'_>> {
-            self.deref().pack_entry_by_location(object)
+        fn bundle_by_pack_id(&self, pack_id: u32) -> Option<&Bundle> {
+            self.deref().bundle_by_pack_id(pack_id)
+        }
+
+        fn entry_by_location(&self, object: &crate::bundle::Location) -> Option<Entry<'_>> {
+            self.deref().entry_by_location(object)
         }
     }
 
@@ -263,12 +275,16 @@ mod find_impls {
             self.deref().find(id, buffer, pack_cache)
         }
 
-        fn location_by_id(&self, id: impl AsRef<oid>, buf: &mut Vec<u8>) -> Option<Location> {
-            self.deref().location_by_id(id, buf)
+        fn location_by_oid(&self, id: impl AsRef<oid>, buf: &mut Vec<u8>) -> Option<Location> {
+            self.deref().location_by_oid(id, buf)
         }
 
-        fn pack_entry_by_location(&self, location: &crate::bundle::Location) -> Option<PackEntry<'_>> {
-            self.deref().pack_entry_by_location(location)
+        fn bundle_by_pack_id(&self, pack_id: u32) -> Option<&Bundle> {
+            self.deref().bundle_by_pack_id(pack_id)
+        }
+
+        fn entry_by_location(&self, location: &crate::bundle::Location) -> Option<Entry<'_>> {
+            self.deref().entry_by_location(location)
         }
     }
 }
